
/* Generated data (by glib-mkenums) */

#include "ggit-enum-types.h"

/* enumerations from "ggit-types.h" */
#include "ggit-types.h"

GType
ggit_branch_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_BRANCH_LOCAL,
			  "GGIT_BRANCH_LOCAL",
			  "local" },
			{ GGIT_BRANCH_REMOTE,
			  "GGIT_BRANCH_REMOTE",
			  "remote" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitBranchType"),
				values);
	}
	return the_type;
}

GType
ggit_cap_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_CAP_THREADS,
			  "GGIT_CAP_THREADS",
			  "threads" },
			{ GGIT_CAP_HTTPS,
			  "GGIT_CAP_HTTPS",
			  "https" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitCapFlags"),
				values);
	}
	return the_type;
}

GType
ggit_blame_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_BLAME_NORMAL,
			  "GGIT_BLAME_NORMAL",
			  "normal" },
			{ GGIT_BLAME_TRACK_COPIES_SAME_FILE,
			  "GGIT_BLAME_TRACK_COPIES_SAME_FILE",
			  "track-copies-same-file" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitBlameFlags"),
				values);
	}
	return the_type;
}

GType
ggit_config_level_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_CONFIG_LEVEL_SYSTEM,
			  "GGIT_CONFIG_LEVEL_SYSTEM",
			  "system" },
			{ GGIT_CONFIG_LEVEL_XDG,
			  "GGIT_CONFIG_LEVEL_XDG",
			  "xdg" },
			{ GGIT_CONFIG_LEVEL_GLOBAL,
			  "GGIT_CONFIG_LEVEL_GLOBAL",
			  "global" },
			{ GGIT_CONFIG_LEVEL_LOCAL,
			  "GGIT_CONFIG_LEVEL_LOCAL",
			  "local" },
			{ GGIT_CONFIG_LEVEL_HIGHEST,
			  "GGIT_CONFIG_LEVEL_HIGHEST",
			  "highest" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitConfigLevel"),
				values);
	}
	return the_type;
}

GType
ggit_create_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_CREATE_NONE,
			  "GGIT_CREATE_NONE",
			  "none" },
			{ GGIT_CREATE_FORCE,
			  "GGIT_CREATE_FORCE",
			  "force" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitCreateFlags"),
				values);
	}
	return the_type;
}

GType
ggit_delta_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_DELTA_UNMODIFIED,
			  "GGIT_DELTA_UNMODIFIED",
			  "unmodified" },
			{ GGIT_DELTA_ADDED,
			  "GGIT_DELTA_ADDED",
			  "added" },
			{ GGIT_DELTA_DELETED,
			  "GGIT_DELTA_DELETED",
			  "deleted" },
			{ GGIT_DELTA_MODIFIED,
			  "GGIT_DELTA_MODIFIED",
			  "modified" },
			{ GGIT_DELTA_RENAMED,
			  "GGIT_DELTA_RENAMED",
			  "renamed" },
			{ GGIT_DELTA_COPIED,
			  "GGIT_DELTA_COPIED",
			  "copied" },
			{ GGIT_DELTA_IGNORED,
			  "GGIT_DELTA_IGNORED",
			  "ignored" },
			{ GGIT_DELTA_UNTRACKED,
			  "GGIT_DELTA_UNTRACKED",
			  "untracked" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitDeltaType"),
				values);
	}
	return the_type;
}

GType
ggit_diff_format_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_DIFF_FORMAT_PATCH,
			  "GGIT_DIFF_FORMAT_PATCH",
			  "patch" },
			{ GGIT_DIFF_FORMAT_PATCH_HEADER,
			  "GGIT_DIFF_FORMAT_PATCH_HEADER",
			  "patch-header" },
			{ GGIT_DIFF_FORMAT_RAW,
			  "GGIT_DIFF_FORMAT_RAW",
			  "raw" },
			{ GGIT_DIFF_FORMAT_NAME_ONLY,
			  "GGIT_DIFF_FORMAT_NAME_ONLY",
			  "name-only" },
			{ GGIT_DIFF_FORMAT_NAME_STATUS,
			  "GGIT_DIFF_FORMAT_NAME_STATUS",
			  "name-status" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitDiffFormatType"),
				values);
	}
	return the_type;
}

GType
ggit_diff_option_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_DIFF_NORMAL,
			  "GGIT_DIFF_NORMAL",
			  "normal" },
			{ GGIT_DIFF_REVERSE,
			  "GGIT_DIFF_REVERSE",
			  "reverse" },
			{ GGIT_DIFF_INCLUDE_IGNORED,
			  "GGIT_DIFF_INCLUDE_IGNORED",
			  "include-ignored" },
			{ GGIT_DIFF_RECURSE_IGNORED_DIRS,
			  "GGIT_DIFF_RECURSE_IGNORED_DIRS",
			  "recurse-ignored-dirs" },
			{ GGIT_DIFF_INCLUDE_UNTRACKED,
			  "GGIT_DIFF_INCLUDE_UNTRACKED",
			  "include-untracked" },
			{ GGIT_DIFF_RECURSE_UNTRACKED_DIRS,
			  "GGIT_DIFF_RECURSE_UNTRACKED_DIRS",
			  "recurse-untracked-dirs" },
			{ GGIT_DIFF_INCLUDE_UNMODIFIED,
			  "GGIT_DIFF_INCLUDE_UNMODIFIED",
			  "include-unmodified" },
			{ GGIT_DIFF_INCLUDE_TYPECHANGE,
			  "GGIT_DIFF_INCLUDE_TYPECHANGE",
			  "include-typechange" },
			{ GGIT_DIFF_INCLUDE_TYPECHANGE_TREES,
			  "GGIT_DIFF_INCLUDE_TYPECHANGE_TREES",
			  "include-typechange-trees" },
			{ GGIT_DIFF_IGNORE_FILE_MODE,
			  "GGIT_DIFF_IGNORE_FILE_MODE",
			  "ignore-file-mode" },
			{ GGIT_DIFF_IGNORE_SUBMODULES,
			  "GGIT_DIFF_IGNORE_SUBMODULES",
			  "ignore-submodules" },
			{ GGIT_DIFF_IGNORE_CASE,
			  "GGIT_DIFF_IGNORE_CASE",
			  "ignore-case" },
			{ GGIT_DIFF_DISABLE_PATHSPEC_MATCH,
			  "GGIT_DIFF_DISABLE_PATHSPEC_MATCH",
			  "disable-pathspec-match" },
			{ GGIT_DIFF_SKIP_BINARY_CHECK,
			  "GGIT_DIFF_SKIP_BINARY_CHECK",
			  "skip-binary-check" },
			{ GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS,
			  "GGIT_DIFF_ENABLE_FAST_UNTRACKED_DIRS",
			  "enable-fast-untracked-dirs" },
			{ GGIT_DIFF_FORCE_TEXT,
			  "GGIT_DIFF_FORCE_TEXT",
			  "force-text" },
			{ GGIT_DIFF_FORCE_BINARY,
			  "GGIT_DIFF_FORCE_BINARY",
			  "force-binary" },
			{ GGIT_DIFF_IGNORE_WHITESPACE,
			  "GGIT_DIFF_IGNORE_WHITESPACE",
			  "ignore-whitespace" },
			{ GGIT_DIFF_IGNORE_WHITESPACE_CHANGE,
			  "GGIT_DIFF_IGNORE_WHITESPACE_CHANGE",
			  "ignore-whitespace-change" },
			{ GGIT_DIFF_IGNORE_WHITESPACE_EOL,
			  "GGIT_DIFF_IGNORE_WHITESPACE_EOL",
			  "ignore-whitespace-eol" },
			{ GGIT_DIFF_SHOW_UNTRACKED_CONTENT,
			  "GGIT_DIFF_SHOW_UNTRACKED_CONTENT",
			  "show-untracked-content" },
			{ GGIT_DIFF_SHOW_UNMODIFIED,
			  "GGIT_DIFF_SHOW_UNMODIFIED",
			  "show-unmodified" },
			{ GGIT_DIFF_PATIENCE,
			  "GGIT_DIFF_PATIENCE",
			  "patience" },
			{ GGIT_DIFF_MINIMAL,
			  "GGIT_DIFF_MINIMAL",
			  "minimal" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitDiffOption"),
				values);
	}
	return the_type;
}

GType
ggit_diff_flag_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_DIFF_FLAG_BINARY,
			  "GGIT_DIFF_FLAG_BINARY",
			  "binary" },
			{ GGIT_DIFF_FLAG_NOT_BINARY,
			  "GGIT_DIFF_FLAG_NOT_BINARY",
			  "not-binary" },
			{ GGIT_DIFF_FLAG_VALID_OID,
			  "GGIT_DIFF_FLAG_VALID_OID",
			  "valid-oid" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitDiffFlag"),
				values);
	}
	return the_type;
}

GType
ggit_diff_line_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_DIFF_LINE_CONTEXT,
			  "GGIT_DIFF_LINE_CONTEXT",
			  "context" },
			{ GGIT_DIFF_LINE_ADDITION,
			  "GGIT_DIFF_LINE_ADDITION",
			  "addition" },
			{ GGIT_DIFF_LINE_DELETION,
			  "GGIT_DIFF_LINE_DELETION",
			  "deletion" },
			{ GGIT_DIFF_LINE_CONTEXT_EOFNL,
			  "GGIT_DIFF_LINE_CONTEXT_EOFNL",
			  "context-eofnl" },
			{ GGIT_DIFF_LINE_ADD_EOFNL,
			  "GGIT_DIFF_LINE_ADD_EOFNL",
			  "add-eofnl" },
			{ GGIT_DIFF_LINE_DEL_EOFNL,
			  "GGIT_DIFF_LINE_DEL_EOFNL",
			  "del-eofnl" },
			{ GGIT_DIFF_LINE_FILE_HDR,
			  "GGIT_DIFF_LINE_FILE_HDR",
			  "file-hdr" },
			{ GGIT_DIFF_LINE_HUNK_HDR,
			  "GGIT_DIFF_LINE_HUNK_HDR",
			  "hunk-hdr" },
			{ GGIT_DIFF_LINE_BINARY,
			  "GGIT_DIFF_LINE_BINARY",
			  "binary" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitDiffLineType"),
				values);
	}
	return the_type;
}

GType
ggit_error_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_ERROR_GIT_ERROR,
			  "GGIT_ERROR_GIT_ERROR",
			  "git-error" },
			{ GGIT_ERROR_NOTFOUND,
			  "GGIT_ERROR_NOTFOUND",
			  "notfound" },
			{ GGIT_ERROR_EXISTS,
			  "GGIT_ERROR_EXISTS",
			  "exists" },
			{ GGIT_ERROR_AMBIGUOUS,
			  "GGIT_ERROR_AMBIGUOUS",
			  "ambiguous" },
			{ GGIT_ERROR_BUFS,
			  "GGIT_ERROR_BUFS",
			  "bufs" },
			{ GGIT_ERROR_PASSTHROUGH,
			  "GGIT_ERROR_PASSTHROUGH",
			  "passthrough" },
			{ GGIT_ERROR_ITEROVER,
			  "GGIT_ERROR_ITEROVER",
			  "iterover" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitError"),
				values);
	}
	return the_type;
}

GType
ggit_file_mode_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_FILE_MODE_NEW,
			  "GGIT_FILE_MODE_NEW",
			  "new" },
			{ GGIT_FILE_MODE_TREE,
			  "GGIT_FILE_MODE_TREE",
			  "tree" },
			{ GGIT_FILE_MODE_BLOB,
			  "GGIT_FILE_MODE_BLOB",
			  "blob" },
			{ GGIT_FILE_MODE_BLOB_EXECUTABLE,
			  "GGIT_FILE_MODE_BLOB_EXECUTABLE",
			  "blob-executable" },
			{ GGIT_FILE_MODE_LINK,
			  "GGIT_FILE_MODE_LINK",
			  "link" },
			{ GGIT_FILE_MODE_COMMIT,
			  "GGIT_FILE_MODE_COMMIT",
			  "commit" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitFileMode"),
				values);
	}
	return the_type;
}

GType
ggit_merge_automerge_mode_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_MERGE_AUTOMERGE_MODE_NORMAL,
			  "GGIT_MERGE_AUTOMERGE_MODE_NORMAL",
			  "normal" },
			{ GGIT_MERGE_AUTOMERGE_MODE_NONE,
			  "GGIT_MERGE_AUTOMERGE_MODE_NONE",
			  "none" },
			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS,
			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_OURS",
			  "favor-ours" },
			{ GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS,
			  "GGIT_MERGE_AUTOMERGE_MODE_FAVOR_THEIRS",
			  "favor-theirs" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitMergeAutomergeMode"),
				values);
	}
	return the_type;
}

GType
ggit_merge_tree_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_MERGE_TREE_FIND_RENAMES,
			  "GGIT_MERGE_TREE_FIND_RENAMES",
			  "renames" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitMergeTreeFlags"),
				values);
	}
	return the_type;
}

GType
ggit_remote_download_tags_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_REMOTE_DOWNLOAD_TAGS_AUTO,
			  "GGIT_REMOTE_DOWNLOAD_TAGS_AUTO",
			  "auto" },
			{ GGIT_REMOTE_DOWNLOAD_TAGS_NONE,
			  "GGIT_REMOTE_DOWNLOAD_TAGS_NONE",
			  "none" },
			{ GGIT_REMOTE_DOWNLOAD_TAGS_ALL,
			  "GGIT_REMOTE_DOWNLOAD_TAGS_ALL",
			  "all" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitRemoteDownloadTagsType"),
				values);
	}
	return the_type;
}

GType
ggit_remote_completion_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_REMOTE_COMPLETION_DOWNLOAD,
			  "GGIT_REMOTE_COMPLETION_DOWNLOAD",
			  "download" },
			{ GGIT_REMOTE_COMPLETION_INDEXING,
			  "GGIT_REMOTE_COMPLETION_INDEXING",
			  "indexing" },
			{ GGIT_REMOTE_COMPLETION_ERROR,
			  "GGIT_REMOTE_COMPLETION_ERROR",
			  "error" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitRemoteCompletionType"),
				values);
	}
	return the_type;
}

GType
ggit_ref_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_REF_INVALID,
			  "GGIT_REF_INVALID",
			  "invalid" },
			{ GGIT_REF_OID,
			  "GGIT_REF_OID",
			  "oid" },
			{ GGIT_REF_SYMBOLIC,
			  "GGIT_REF_SYMBOLIC",
			  "symbolic" },
			{ GGIT_REF_LISTALL,
			  "GGIT_REF_LISTALL",
			  "listall" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitRefType"),
				values);
	}
	return the_type;
}

GType
ggit_reset_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_RESET_SOFT,
			  "GGIT_RESET_SOFT",
			  "soft" },
			{ GGIT_RESET_MIXED,
			  "GGIT_RESET_MIXED",
			  "mixed" },
			{ GGIT_RESET_HARD,
			  "GGIT_RESET_HARD",
			  "hard" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitResetType"),
				values);
	}
	return the_type;
}

GType
ggit_sort_mode_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_SORT_NONE,
			  "GGIT_SORT_NONE",
			  "none" },
			{ GGIT_SORT_TOPOLOGICAL,
			  "GGIT_SORT_TOPOLOGICAL",
			  "topological" },
			{ GGIT_SORT_TIME,
			  "GGIT_SORT_TIME",
			  "time" },
			{ GGIT_SORT_REVERSE,
			  "GGIT_SORT_REVERSE",
			  "reverse" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitSortMode"),
				values);
	}
	return the_type;
}

GType
ggit_stash_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_STASH_DEFAULT,
			  "GGIT_STASH_DEFAULT",
			  "default" },
			{ GGIT_STASH_KEEP_INDEX,
			  "GGIT_STASH_KEEP_INDEX",
			  "keep-index" },
			{ GGIT_STASH_INCLUDE_UNTRACKED,
			  "GGIT_STASH_INCLUDE_UNTRACKED",
			  "include-untracked" },
			{ GGIT_STASH_INCLUDE_IGNORED,
			  "GGIT_STASH_INCLUDE_IGNORED",
			  "include-ignored" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitStashFlags"),
				values);
	}
	return the_type;
}

GType
ggit_status_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_STATUS_CURRENT,
			  "GGIT_STATUS_CURRENT",
			  "current" },
			{ GGIT_STATUS_INDEX_NEW,
			  "GGIT_STATUS_INDEX_NEW",
			  "index-new" },
			{ GGIT_STATUS_INDEX_MODIFIED,
			  "GGIT_STATUS_INDEX_MODIFIED",
			  "index-modified" },
			{ GGIT_STATUS_INDEX_DELETED,
			  "GGIT_STATUS_INDEX_DELETED",
			  "index-deleted" },
			{ GGIT_STATUS_INDEX_RENAMED,
			  "GGIT_STATUS_INDEX_RENAMED",
			  "index-renamed" },
			{ GGIT_STATUS_INDEX_TYPECHANGE,
			  "GGIT_STATUS_INDEX_TYPECHANGE",
			  "index-typechange" },
			{ GGIT_STATUS_WORKING_TREE_NEW,
			  "GGIT_STATUS_WORKING_TREE_NEW",
			  "working-tree-new" },
			{ GGIT_STATUS_WORKING_TREE_MODIFIED,
			  "GGIT_STATUS_WORKING_TREE_MODIFIED",
			  "working-tree-modified" },
			{ GGIT_STATUS_WORKING_TREE_DELETED,
			  "GGIT_STATUS_WORKING_TREE_DELETED",
			  "working-tree-deleted" },
			{ GGIT_STATUS_WORKING_TREE_TYPECHANGE,
			  "GGIT_STATUS_WORKING_TREE_TYPECHANGE",
			  "working-tree-typechange" },
			{ GGIT_STATUS_IGNORED,
			  "GGIT_STATUS_IGNORED",
			  "ignored" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitStatusFlags"),
				values);
	}
	return the_type;
}

GType
ggit_submodule_ignore_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_SUBMODULE_IGNORE_RESET,
			  "GGIT_SUBMODULE_IGNORE_RESET",
			  "reset" },
			{ GGIT_SUBMODULE_IGNORE_NONE,
			  "GGIT_SUBMODULE_IGNORE_NONE",
			  "none" },
			{ GGIT_SUBMODULE_IGNORE_UNTRACKED,
			  "GGIT_SUBMODULE_IGNORE_UNTRACKED",
			  "untracked" },
			{ GGIT_SUBMODULE_IGNORE_DIRTY,
			  "GGIT_SUBMODULE_IGNORE_DIRTY",
			  "dirty" },
			{ GGIT_SUBMODULE_IGNORE_ALL,
			  "GGIT_SUBMODULE_IGNORE_ALL",
			  "all" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitSubmoduleIgnore"),
				values);
	}
	return the_type;
}

GType
ggit_submodule_status_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_SUBMODULE_STATUS_IN_HEAD,
			  "GGIT_SUBMODULE_STATUS_IN_HEAD",
			  "in-head" },
			{ GGIT_SUBMODULE_STATUS_IN_INDEX,
			  "GGIT_SUBMODULE_STATUS_IN_INDEX",
			  "in-index" },
			{ GGIT_SUBMODULE_STATUS_IN_CONFIG,
			  "GGIT_SUBMODULE_STATUS_IN_CONFIG",
			  "in-config" },
			{ GGIT_SUBMODULE_STATUS_IN_WD,
			  "GGIT_SUBMODULE_STATUS_IN_WD",
			  "in-wd" },
			{ GGIT_SUBMODULE_STATUS_INDEX_ADDED,
			  "GGIT_SUBMODULE_STATUS_INDEX_ADDED",
			  "index-added" },
			{ GGIT_SUBMODULE_STATUS_INDEX_DELETED,
			  "GGIT_SUBMODULE_STATUS_INDEX_DELETED",
			  "index-deleted" },
			{ GGIT_SUBMODULE_STATUS_INDEX_MODIFIED,
			  "GGIT_SUBMODULE_STATUS_INDEX_MODIFIED",
			  "index-modified" },
			{ GGIT_SUBMODULE_STATUS_WD_UNINITIALIZED,
			  "GGIT_SUBMODULE_STATUS_WD_UNINITIALIZED",
			  "wd-uninitialized" },
			{ GGIT_SUBMODULE_STATUS_WD_ADDED,
			  "GGIT_SUBMODULE_STATUS_WD_ADDED",
			  "wd-added" },
			{ GGIT_SUBMODULE_STATUS_WD_DELETED,
			  "GGIT_SUBMODULE_STATUS_WD_DELETED",
			  "wd-deleted" },
			{ GGIT_SUBMODULE_STATUS_WD_MODIFIED,
			  "GGIT_SUBMODULE_STATUS_WD_MODIFIED",
			  "wd-modified" },
			{ GGIT_SUBMODULE_STATUS_WD_INDEX_MODIFIED,
			  "GGIT_SUBMODULE_STATUS_WD_INDEX_MODIFIED",
			  "wd-index-modified" },
			{ GGIT_SUBMODULE_STATUS_WD_WD_MODIFIED,
			  "GGIT_SUBMODULE_STATUS_WD_WD_MODIFIED",
			  "wd-wd-modified" },
			{ GGIT_SUBMODULE_STATUS_WD_UNTRACKED,
			  "GGIT_SUBMODULE_STATUS_WD_UNTRACKED",
			  "wd-untracked" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitSubmoduleStatus"),
				values);
	}
	return the_type;
}

GType
ggit_submodule_update_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_SUBMODULE_UPDATE_RESET,
			  "GGIT_SUBMODULE_UPDATE_RESET",
			  "reset" },
			{ GGIT_SUBMODULE_UPDATE_CHECKOUT,
			  "GGIT_SUBMODULE_UPDATE_CHECKOUT",
			  "checkout" },
			{ GGIT_SUBMODULE_UPDATE_REBASE,
			  "GGIT_SUBMODULE_UPDATE_REBASE",
			  "rebase" },
			{ GGIT_SUBMODULE_UPDATE_MERGE,
			  "GGIT_SUBMODULE_UPDATE_MERGE",
			  "merge" },
			{ GGIT_SUBMODULE_UPDATE_NONE,
			  "GGIT_SUBMODULE_UPDATE_NONE",
			  "none" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitSubmoduleUpdate"),
				values);
	}
	return the_type;
}

GType
ggit_tree_walk_mode_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_TREE_WALK_MODE_PRE,
			  "GGIT_TREE_WALK_MODE_PRE",
			  "pre" },
			{ GGIT_TREE_WALK_MODE_POST,
			  "GGIT_TREE_WALK_MODE_POST",
			  "post" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitTreeWalkMode"),
				values);
	}
	return the_type;
}

GType
ggit_status_option_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_STATUS_OPTION_INCLUDE_UNTRACKED,
			  "GGIT_STATUS_OPTION_INCLUDE_UNTRACKED",
			  "include-untracked" },
			{ GGIT_STATUS_OPTION_INCLUDE_IGNORED,
			  "GGIT_STATUS_OPTION_INCLUDE_IGNORED",
			  "include-ignored" },
			{ GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED,
			  "GGIT_STATUS_OPTION_INCLUDE_UNMODIFIED",
			  "include-unmodified" },
			{ GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES,
			  "GGIT_STATUS_OPTION_EXCLUDE_SUBMODULES",
			  "exclude-submodules" },
			{ GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS,
			  "GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS",
			  "recurse-untracked-dirs" },
			{ GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH,
			  "GGIT_STATUS_OPTION_DISABLE_PATHSPEC_MATCH",
			  "disable-pathspec-match" },
			{ GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS,
			  "GGIT_STATUS_OPTION_RECURSE_IGNORED_DIRS",
			  "recurse-ignored-dirs" },
			{ GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX,
			  "GGIT_STATUS_OPTION_RENAMES_HEAD_TO_INDEX",
			  "renames-head-to-index" },
			{ GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR,
			  "GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR",
			  "renames-index-to-workdir" },
			{ GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY,
			  "GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY",
			  "sort-case-sensitively" },
			{ GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY,
			  "GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY",
			  "sort-case-insensitively" },
			{ GGIT_STATUS_OPTION_DEFAULT,
			  "GGIT_STATUS_OPTION_DEFAULT",
			  "default" },
			{ GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS,
			  "GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS",
			  "recurse-untracked-dirs" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitStatusOption"),
				values);
	}
	return the_type;
}

GType
ggit_status_show_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ GGIT_STATUS_SHOW_INDEX_AND_WORKDIR,
			  "GGIT_STATUS_SHOW_INDEX_AND_WORKDIR",
			  "index-and-workdir" },
			{ GGIT_STATUS_SHOW_INDEX_ONLY,
			  "GGIT_STATUS_SHOW_INDEX_ONLY",
			  "index-only" },
			{ GGIT_STATUS_SHOW_WORKDIR_ONLY,
			  "GGIT_STATUS_SHOW_WORKDIR_ONLY",
			  "workdir-only" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("GgitStatusShow"),
				values);
	}
	return the_type;
}

GType
ggit_attribute_check_flags_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GFlagsValue values[] = {
			{ GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX,
			  "GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX",
			  "file-then-index" },
			{ GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE,
			  "GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE",
			  "index-then-file" },
			{ GGIT_ATTRIBUTE_CHECK_INDEX_ONLY,
			  "GGIT_ATTRIBUTE_CHECK_INDEX_ONLY",
			  "index-only" },
			{ GGIT_ATTRIBUTE_CHECK_NO_SYSTEM,
			  "GGIT_ATTRIBUTE_CHECK_NO_SYSTEM",
			  "no-system" },
			{ 0, NULL, NULL }
		};
		the_type = g_flags_register_static (
				g_intern_static_string ("GgitAttributeCheckFlags"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

